package main

import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material.Button
import androidx.compose.material.MaterialTheme
import androidx.compose.material.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp

@Composable
fun compareResults(
    glossaryWords: List<Word>,
    codeWords: List<String>,
    onBackClick: () -> Unit
) {
    val commonWords = findCommonWords(glossaryWords, codeWords)

    Column(
        modifier = Modifier.fillMaxSize(),
        verticalArrangement = Arrangement.Top,
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        Text(
            text = "Le code contient ${commonWords.size}% des mots du glossaire",
            style = MaterialTheme.typography.h3
        )

        Spacer(modifier = Modifier.height(16.dp))

        commonWordsTable(glossaryWords, codeWords)

        Spacer(modifier = Modifier.height(16.dp))

        Button(
            onClick = onBackClick,
            colors = androidx.compose.material.ButtonDefaults.buttonColors(
                backgroundColor = customRedColor,
                contentColor = Color.White
            )
        ) {
            Text("Retour")
        }
    }
}

@Composable
fun commonWordsTable(
    glossaryWords: List<Word>,
    codeWords: List<String>
) {
    val glossaryWordsSet = glossaryWords.map { it.name }.toSet()

    LazyColumn(
        modifier = Modifier.fillMaxSize(),
        content = {
            item {
                commonWordsHeaderRow()
            }
            items(glossaryWords) { word ->
                commonWordsDataRow(word.name, codeWords, glossaryWordsSet)
            }
            items(codeWords) { word ->
                if (word !in glossaryWordsSet) {
                    commonWordsDataRow(word, codeWords, glossaryWordsSet)
                }
            }
        }
    )
}

@Composable
fun commonWordsHeaderRow() {
    Row(
        modifier = Modifier
            .fillMaxWidth()
            .background(Color.Gray)
            .border(1.dp, Color.Black),
        verticalAlignment = Alignment.CenterVertically
    ) {
        listOf("Mot du glossaire", "Mot du code", "Présence commune").forEach { header ->
            Text(
                text = header,
                fontWeight = FontWeight.Bold,
                modifier = Modifier.weight(1f).padding(8.dp),
                color = Color.White
            )
        }
    }
}

@Composable
fun commonWordsDataRow(
    word: String,
    codeWords: List<String>,
    glossaryWordsSet: Set<String>
) {
    val modifier = Modifier
        .fillMaxWidth()
        .border(1.dp, Color.Black)
        .padding(8.dp)

    val isCommon = word in codeWords && word in glossaryWordsSet

    val backgroundColor = when {
        isCommon -> Color.Yellow
        word in codeWords -> Color.Blue // Couleur pour les mots du code
        word in glossaryWordsSet -> Color.Green // Couleur pour les mots du glossaire
        else -> Color.White
    }

    Row(
        modifier = modifier.background(backgroundColor),
        verticalAlignment = Alignment.CenterVertically
    ) {
        cellContent(word, modifier)
        cellContent(if (word in codeWords) "Oui" else "Non", modifier)
        cellContent(if (isCommon) "Oui" else "Non", modifier)
    }
}

fun findCommonWords(glossaryWords: List<Word>, codeWords: List<String>): List<String> {
    val glossaryWordsSet = glossaryWords.map { it.name }.toSet()
    return codeWords.filter { it in glossaryWordsSet }
}